pub fn decode_column_value_text(
text: &str,
type_oid: i32,
) -> Result<ElementValue>Expand description
Back-compat alias used by existing tests in the source crate.
pub fn decode_column_value_text(
text: &str,
type_oid: i32,
) -> Result<ElementValue>Back-compat alias used by existing tests in the source crate.