pub fn string_element(s: impl AsRef<str>) -> ElementValueExpand description
Format helper used when a column cannot be converted — preserve as string ElementValue.
pub fn string_element(s: impl AsRef<str>) -> ElementValueFormat helper used when a column cannot be converted — preserve as string ElementValue.