Shared PostgreSQL type conversion for Drasi source and bootstrap plugins.
Both the CDC source and the bootstrap provider convert column values through
PostgresValue::to_element_value so snapshot and live rows emit identical
drasi_core::models::ElementValues.
Re-exports
pub use decode::decode_column_value_text;pub use decode::decode_text_to_element_value;pub use decode::decode_text_to_postgres_value;pub use decode::string_element;pub use oid::array_element_oid;pub use oid::is_array_oid;pub use oid::oid_from_information_schema;pub use oid::BOOL;pub use oid::BYTEA;pub use oid::CHAR;pub use oid::DATE;pub use oid::FLOAT4;pub use oid::FLOAT8;pub use oid::INT2;pub use oid::INT4;pub use oid::INT8;pub use oid::JSON;pub use oid::JSONB;pub use oid::NAME;pub use oid::NUMERIC;pub use oid::TEXT;pub use oid::TIME;pub use oid::TIMESTAMP;pub use oid::TIMESTAMPTZ;pub use oid::UUID;pub use oid::VARCHAR;pub use value::encode_base64;pub use value::parse_bytea_text;pub use value::PostgresValue;